@@ -41,6 +41,9 @@ from .constants import (
     Z_KEY,
 )
 
+# TODO: refactor to reduce this file to under 1000 lines.
+# pylint: disable=C0302
+
 
 class Annotation:
     """Internal base class, not to be used directly.
@@ -105,7 +108,7 @@ class BoxAnnotation(Annotation):  # pylint: disable=R0902
             reference_id="image_1",
             annotation_id="image_1_car_box_1",
             metadata={"vehicle_color": "red"},
-            embedding_vector=[0.1423, 1.432, ...3.829],
+            embedding_vector=[0.1423, 1.432, ..., 3.829],
         )
 
     Parameters:
@@ -310,7 +313,7 @@ class PolygonAnnotation(Annotation):
             reference_id="image_2",
             annotation_id="image_2_bus_polygon_1",
             metadata={"vehicle_color": "yellow"},
-            embedding_vector=[0.1423, 1.432, ...3.829],
+            embedding_vector=[0.1423, 1.432, ..., 3.829],
         )
 
     Parameters:
@@ -691,7 +694,7 @@ class SegmentationAnnotation(Annotation):
         from nucleus import SegmentationAnnotation
 
         segmentation = SegmentationAnnotation(
-            mask_url="s3://your-bucket-name/segmentation-masks/image_2_mask_id1.png",
+            mask_url="s3://your-bucket-name/segmentation-masks/image_2_mask_id_1.png",
             annotations=[
                 Segment(label="grass", index="1"),
                 Segment(label="road", index="2"),
@@ -704,7 +707,8 @@ class SegmentationAnnotation(Annotation):
 
     Parameters:
         mask_url (str): A URL pointing to the segmentation prediction mask which is
-          accessible to Scale, or a local path. The mask is an HxW int8 array saved in PNG format,
+          accessible to Scale. This "URL" can also be a path to a local file.
+          The mask is an HxW int8 array saved in PNG format,
           with each pixel value ranging from [0, N), where N is the number of
           possible classes (for semantic segmentation) or instances (for instance
           segmentation).
@@ -892,6 +896,53 @@ class MultiCategoryAnnotation(Annotation):
         return payload
 
 
+@dataclass
+class SceneCategoryAnnotation(Annotation):
+    """A scene category annotation.
+
+    ::
+
+        from nucleus import CategoryAnnotation
+
+        category = SceneCategoryAnnotation(
+            label="running",
+            reference_id="scene_1",
+            taxonomy_name="action",
+        )
+
+    Parameters:
+        label (str): The label for this annotation.
+        reference_id (str): User-defined ID of the scene to which to apply this annotation.
+        taxonomy_name (Optional[str]): The name of the taxonomy this annotation conforms to.
+          See :meth:`Dataset.add_taxonomy`.
+    """
+
+    label: str
+    reference_id: str
+    taxonomy_name: Optional[str] = None
+    # todo(546247): add metadata support when required
+    metadata: Optional[Dict] = field(default_factory=dict)
+
+    @classmethod
+    def from_json(cls, payload: dict):
+        return cls(
+            label=payload[LABEL_KEY],
+            reference_id=payload[REFERENCE_ID_KEY],
+            taxonomy_name=payload.get(TAXONOMY_NAME_KEY, None),
+        )
+
+    def to_payload(self) -> dict:
+        payload = {
+            LABEL_KEY: self.label,
+            TYPE_KEY: CATEGORY_TYPE,
+            GEOMETRY_KEY: {},
+            REFERENCE_ID_KEY: self.reference_id,
+        }
+        if self.taxonomy_name is not None:
+            payload[TAXONOMY_NAME_KEY] = self.taxonomy_name
+        return payload
+
+
 @dataclass
 class AnnotationList:
     """Wrapper class separating a list of annotations by type."""
@@ -909,6 +960,9 @@ class AnnotationList:
     multi_category_annotations: List[MultiCategoryAnnotation] = field(
         default_factory=list
     )
+    scene_category_annotations: List[SceneCategoryAnnotation] = field(
+        default_factory=list
+    )
     segmentation_annotations: List[SegmentationAnnotation] = field(
         default_factory=list
     )
@@ -933,6 +987,8 @@ class AnnotationList:
                 self.category_annotations.append(annotation)
             elif isinstance(annotation, MultiCategoryAnnotation):
                 self.multi_category_annotations.append(annotation)
+            elif isinstance(annotation, SceneCategoryAnnotation):
+                self.scene_category_annotations.append(annotation)
             else:
                 assert isinstance(
                     annotation, SegmentationAnnotation
@@ -951,6 +1007,7 @@ class AnnotationList:
             + len(self.cuboid_annotations)
             + len(self.category_annotations)
             + len(self.multi_category_annotations)
+            + len(self.scene_category_annotations)
             + len(self.segmentation_annotations)
         )
 
