@@ -1,59 +1,52 @@
+import logging
 import sys
 from functools import wraps
-from typing import Dict, List, Tuple, TypeVar
+from typing import Dict, List, Tuple
 
 import numpy as np
 from scipy.optimize import linear_sum_assignment
 
 from nucleus.annotation import BoxAnnotation, PolygonAnnotation
-from nucleus.prediction import BoxPrediction, PolygonPrediction
+
+from .custom_types import BoxOrPolygonAnnotation, BoxOrPolygonPrediction
+
+try:
+    from shapely.geometry import Polygon
+except (ModuleNotFoundError, OSError):
+    from ..package_not_installed import PackageNotInstalled
+
+    Polygon = PackageNotInstalled
+
 
 from .base import ScalarResult
 from .errors import PolygonAnnotationTypeError
-from .geometry import GeometryPolygon, polygon_intersection_area
-
-BoxOrPolygonPrediction = TypeVar(
-    "BoxOrPolygonPrediction", BoxPrediction, PolygonPrediction
-)
-BoxOrPolygonAnnotation = TypeVar(
-    "BoxOrPolygonAnnotation", BoxAnnotation, PolygonAnnotation
-)
-BoxOrPolygonAnnoOrPred = TypeVar(
-    "BoxOrPolygonAnnoOrPred",
-    BoxAnnotation,
-    PolygonAnnotation,
-    BoxPrediction,
-    PolygonPrediction,
-)
 
 
-def polygon_annotation_to_geometry(
+def polygon_annotation_to_shape(
     annotation: BoxOrPolygonAnnotation,
-) -> GeometryPolygon:
+) -> Polygon:
     if isinstance(annotation, BoxAnnotation):
         xmin = annotation.x - annotation.width / 2
         xmax = annotation.x + annotation.width / 2
         ymin = annotation.y - annotation.height / 2
         ymax = annotation.y + annotation.height / 2
-        points = [(xmin, ymin), (xmax, ymin), (xmax, ymax), (xmin, ymax)]
-        return GeometryPolygon(points=points, is_rectangle=True)
-    elif isinstance(annotation, PolygonAnnotation):
-        return GeometryPolygon(
-            points=[(point.x, point.y) for point in annotation.vertices],
-            is_rectangle=False,
+        return Polygon(
+            [(xmin, ymin), (xmax, ymin), (xmax, ymax), (xmin, ymax)]
         )
+    elif isinstance(annotation, PolygonAnnotation):
+        return Polygon([(point.x, point.y) for point in annotation.vertices])
     else:
         raise PolygonAnnotationTypeError()
 
 
-def _iou(annotation: GeometryPolygon, prediction: GeometryPolygon) -> float:
-    intersection = polygon_intersection_area(annotation, prediction)
+def _iou(annotation: Polygon, prediction: Polygon) -> float:
+    intersection = annotation.intersection(prediction).area
     union = annotation.area + prediction.area - intersection
     return intersection / max(union, sys.float_info.epsilon)
 
 
 def _iou_matrix(
-    annotations: List[GeometryPolygon], predictions: List[GeometryPolygon]
+    annotations: List[Polygon], predictions: List[Polygon]
 ) -> np.ndarray:
     iou_matrix = np.empty((len(predictions), len(annotations)))
     for i, prediction in enumerate(predictions):
@@ -80,13 +73,43 @@ def _iou_assignments_for_same_reference_id(
         len(reference_ids) <= 1
     ), "Expected annotations and predictions to have same reference ID."
 
-    # Convert annotation and predictions to GeometryPolygon objects
-    polygon_annotations = list(
-        map(polygon_annotation_to_geometry, annotations)
-    )
-    polygon_predictions = list(
-        map(polygon_annotation_to_geometry, predictions)
-    )
+    # Convert annotation and predictions to shapely.geometry.Polygon objects
+    polygon_annotations = list(map(polygon_annotation_to_shape, annotations))
+    polygon_predictions = list(map(polygon_annotation_to_shape, predictions))
+
+    invalid_anns = [
+        ann
+        for ann, poly in zip(annotations, polygon_annotations)
+        if not poly.is_valid
+    ]
+    invalid_preds = [
+        pred
+        for pred, poly in zip(predictions, polygon_predictions)
+        if not poly.is_valid
+    ]
+
+    if invalid_anns or invalid_preds:
+        # Filter out invalid polys
+        polygon_annotations = [
+            poly
+            for ann, poly in zip(annotations, polygon_annotations)
+            if poly.is_valid
+        ]
+        polygon_predictions = [
+            poly
+            for pred, poly in zip(predictions, polygon_predictions)
+            if poly.is_valid
+        ]
+        invalid_dataset_ids = set(
+            ann.reference_id for ann in invalid_anns
+        ).union(set(pred.reference_id for pred in invalid_preds))
+        # TODO(gunnar): change to .id once field is surfaced)
+        logging.warning(
+            "Invalid polygons for dataset items: %s Annotations:%s, predictions: %s",
+            invalid_dataset_ids,
+            [a.annotation_id for a in invalid_anns],
+            [p.annotation_id for p in invalid_preds],
+        )
 
     # Compute IoU matrix and set IoU values below the threshold to 0.
     iou_matrix = _iou_matrix(polygon_annotations, polygon_predictions)
